package com.ruoyi.ems.mapper;

import com.ruoyi.ems.domain.EmsObjAbility;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 能源对象能力Mapper接口
 *
 * @author ruoyi
 * @date 2024-09-23
 */
public interface EmsObjAbilityMapper {
    /**
     * 查询能源对象能力
     *
     * @param id 能源对象能力主键
     * @return 能源对象能力
     */
    EmsObjAbility selectObjAbilityById(Long id);

    /**
     * 查询能源对象能力列表
     *
     * @param ObjAbility 能源对象能力
     * @return 能源对象能力集合
     */
    List<EmsObjAbility> selectObjAbilityList(EmsObjAbility ObjAbility);

    /**
     * 根据modelCode查询能源对象能力列表
     *
     * @param modelCode 设备模型代码
     * @return 能源对象能力集合
     */
    List<EmsObjAbility> selectByModelCode(@Param("modelCode") String modelCode);

    /**
     * 新增能源对象能力
     *
     * @param ObjAbility 能源对象能力
     * @return 结果
     */
    int insertObjAbility(EmsObjAbility ObjAbility);

    /**
     * 批量新增能源对象能力
     *
     * @param list 能源对象能力
     * @return 结果
     */
    int insertBatch(List<EmsObjAbility> list);

    /**
     * 修改能源对象能力
     *
     * @param ObjAbility 能源对象能力
     * @return 结果
     */
    int updateObjAbility(EmsObjAbility ObjAbility);

    /**
     * 删除能源对象能力
     *
     * @param id 能源对象能力主键
     * @return 结果
     */
    int deleteObjAbilityById(Long id);

    /**
     * 根据modelCode删除能源对象能力
     *
     * @param modelCode 设备模型代码
     * @return 结果
     */
    int deleteByModelCode(@Param("modelCode") String modelCode);

    /**
     * 批量删除能源对象能力
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteObjAbilityByIds(Long[] ids);
}
